==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/traffic_portal/app/src/scripts/shared-libs.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Define the required js libraries needed for this application. The compiler will merge them all into a single download. Order is important!
 */

// angular and angular helpers
require('angular');
require('angular-animate');
require('angular-resource');
require('angular-route');
require('angular-sanitize');
require('angular-ui-router');

// angular jwt
require('angular-jwt');

// angular loading bar
require('loading-bar');

// angular bootstrap
require('ui-bootstrap');
require('ui-bootstrap-tpls');

// angular bootstrap context menu
require('contextMenu');

// jquery
window.$ = window.jQuery = require('jquery');

// flot charts
require('jquery-flot');
require('jquery-flot-pie');
require('jquery-flot-stack');
require('jquery-flot-time');
require('jquery-flot-tooltip');
require('jquery-flot-axislabels');

// misc
require('es5-shim');
require('json3');

==> apache-trafficcontrol-8.0.0.tar.gz: apache-trafficcontrol-8.0.0/traffic_portal/app/src/scripts/shared-libs.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/**
 * Define the required js libraries needed for this application. The compiler will merge them all into a single download. Order is important!
 */

// angular and angular helpers
require('angular');
require('angular-animate');
require('angular-resource');
require('angular-route');
require('angular-sanitize');
require('angular-ui-router');

// angular jwt
require('angular-jwt');

// angular loading bar
require('loading-bar');

// angular bootstrap
require('ui-bootstrap');
require('ui-bootstrap-tpls');

// angular bootstrap context menu
require('contextMenu');

// jquery
window.$ = window.jQuery = require('jquery');

// flot charts
require('jquery-flot');
require('jquery-flot-pie');
require('jquery-flot-stack');
require('jquery-flot-time');
require('jquery-flot-tooltip');
require('jquery-flot-axislabels');

/** @typedef { import("node-forge") } forge */
window.forge = require("node-forge");
